cmd

package
v0.0.0-...-2169a8c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 21, 2020 License: MPL-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type App

type App struct {
	Kong *kong.Context
}

App is passed to the Run function for commands

type CLI

type CLI struct {
	Link    Link             `cmd:"true"`
	Version kong.VersionFlag `name:"version" help:"Print version information and quit"`
}

CLI represents the commands, flags, and args possible for backport

type Link struct {
	Config string `arg:"true" help:"Path to configuration file" type:"existingfile" default:"./backport.yaml"`
}

func (*Link) Run

func (l *Link) Run(app *App) error

Jump to